=========================================
Using StepScan
=========================================

This section describes how to use a StepScan from python scripts.  See
:ref:`scan_concepts-label` for a description of terms and basic concepts.


Defining a New Scan
====================

To define a new scan, you create a scan object, set up the Positioners,
Detectors, and Counters for the scan, add optional extra features such a
as extra_pvs and breakpoints, and then run the scan.


Running a Scan
====================



